pub struct RenderVisibleEntities {
pub classes: TypeIdMap<RenderVisibleEntitiesClass>,
}Expand description
Stores a list of all entities that are visible from a single view or subview, as well as the change lists.
This component is only placed directly on camera entities. Lights instead
have a RenderShadowMapVisibleEntities component that contains one or
more RenderVisibleEntities components, one for each cascade or cubemap
side.
The crate::camera::extract_cameras and extract_lights systems create
this object, but they don’t populate it. Instead, the
collect_visible_cpu_culled_entities and
collect_gpu_culled_meshes systems are responsible for
updating this component from the lists of entities in
RenderExtractedVisibleEntities and RenderGpuCulledEntities,
respectively.
Fields
classes: TypeIdMap<RenderVisibleEntitiesClass>Entities visible from this view or subview, sorted by
VisibilityClass.
Implementations
Sourceimpl RenderVisibleEntities
impl RenderVisibleEntities
Sourcepub fn get<QF>(&self) -> Option<&RenderVisibleEntitiesClass>where
QF: 'static,
pub fn get<QF>(&self) -> Option<&RenderVisibleEntitiesClass>where
QF: 'static,
Returns the RenderVisibleEntitiesClass corresponding to the given
VisibilityClass.